Documentation
¶
Overview ¶
Package fake has the automatically generated clients.
Index ¶
- type FakeImageImports
- func (c *FakeImageImports) Create(ctx context.Context, imageImport *v1beta1.ImageImport, opts v1.CreateOptions) (result *v1beta1.ImageImport, err error)
- func (c *FakeImageImports) Delete(ctx context.Context, name string, opts v1.DeleteOptions) error
- func (c *FakeImageImports) DeleteCollection(ctx context.Context, opts v1.DeleteOptions, listOpts v1.ListOptions) error
- func (c *FakeImageImports) Get(ctx context.Context, name string, options v1.GetOptions) (result *v1beta1.ImageImport, err error)
- func (c *FakeImageImports) List(ctx context.Context, opts v1.ListOptions) (result *v1beta1.ImageImportList, err error)
- func (c *FakeImageImports) Patch(ctx context.Context, name string, pt types.PatchType, data []byte, ...) (result *v1beta1.ImageImport, err error)
- func (c *FakeImageImports) Update(ctx context.Context, imageImport *v1beta1.ImageImport, opts v1.UpdateOptions) (result *v1beta1.ImageImport, err error)
- func (c *FakeImageImports) UpdateStatus(ctx context.Context, imageImport *v1beta1.ImageImport, opts v1.UpdateOptions) (*v1beta1.ImageImport, error)
- func (c *FakeImageImports) Watch(ctx context.Context, opts v1.ListOptions) (watch.Interface, error)
- type FakeImages
- func (c *FakeImages) Create(ctx context.Context, image *v1beta1.Image, opts v1.CreateOptions) (result *v1beta1.Image, err error)
- func (c *FakeImages) Delete(ctx context.Context, name string, opts v1.DeleteOptions) error
- func (c *FakeImages) DeleteCollection(ctx context.Context, opts v1.DeleteOptions, listOpts v1.ListOptions) error
- func (c *FakeImages) Get(ctx context.Context, name string, options v1.GetOptions) (result *v1beta1.Image, err error)
- func (c *FakeImages) List(ctx context.Context, opts v1.ListOptions) (result *v1beta1.ImageList, err error)
- func (c *FakeImages) Patch(ctx context.Context, name string, pt types.PatchType, data []byte, ...) (result *v1beta1.Image, err error)
- func (c *FakeImages) Update(ctx context.Context, image *v1beta1.Image, opts v1.UpdateOptions) (result *v1beta1.Image, err error)
- func (c *FakeImages) UpdateStatus(ctx context.Context, image *v1beta1.Image, opts v1.UpdateOptions) (*v1beta1.Image, error)
- func (c *FakeImages) Watch(ctx context.Context, opts v1.ListOptions) (watch.Interface, error)
- type FakeShipwrightV1beta1
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type FakeImageImports ¶
type FakeImageImports struct {
Fake *FakeShipwrightV1beta1
// contains filtered or unexported fields
}
FakeImageImports implements ImageImportInterface
func (*FakeImageImports) Create ¶
func (c *FakeImageImports) Create(ctx context.Context, imageImport *v1beta1.ImageImport, opts v1.CreateOptions) (result *v1beta1.ImageImport, err error)
Create takes the representation of a imageImport and creates it. Returns the server's representation of the imageImport, and an error, if there is any.
func (*FakeImageImports) Delete ¶
func (c *FakeImageImports) Delete(ctx context.Context, name string, opts v1.DeleteOptions) error
Delete takes name of the imageImport and deletes it. Returns an error if one occurs.
func (*FakeImageImports) DeleteCollection ¶
func (c *FakeImageImports) DeleteCollection(ctx context.Context, opts v1.DeleteOptions, listOpts v1.ListOptions) error
DeleteCollection deletes a collection of objects.
func (*FakeImageImports) Get ¶
func (c *FakeImageImports) Get(ctx context.Context, name string, options v1.GetOptions) (result *v1beta1.ImageImport, err error)
Get takes name of the imageImport, and returns the corresponding imageImport object, and an error if there is any.
func (*FakeImageImports) List ¶
func (c *FakeImageImports) List(ctx context.Context, opts v1.ListOptions) (result *v1beta1.ImageImportList, err error)
List takes label and field selectors, and returns the list of ImageImports that match those selectors.
func (*FakeImageImports) Patch ¶
func (c *FakeImageImports) Patch(ctx context.Context, name string, pt types.PatchType, data []byte, opts v1.PatchOptions, subresources ...string) (result *v1beta1.ImageImport, err error)
Patch applies the patch and returns the patched imageImport.
func (*FakeImageImports) Update ¶
func (c *FakeImageImports) Update(ctx context.Context, imageImport *v1beta1.ImageImport, opts v1.UpdateOptions) (result *v1beta1.ImageImport, err error)
Update takes the representation of a imageImport and updates it. Returns the server's representation of the imageImport, and an error, if there is any.
func (*FakeImageImports) UpdateStatus ¶
func (c *FakeImageImports) UpdateStatus(ctx context.Context, imageImport *v1beta1.ImageImport, opts v1.UpdateOptions) (*v1beta1.ImageImport, error)
UpdateStatus was generated because the type contains a Status member. Add a +genclient:noStatus comment above the type to avoid generating UpdateStatus().
func (*FakeImageImports) Watch ¶
func (c *FakeImageImports) Watch(ctx context.Context, opts v1.ListOptions) (watch.Interface, error)
Watch returns a watch.Interface that watches the requested imageImports.
type FakeImages ¶
type FakeImages struct {
Fake *FakeShipwrightV1beta1
// contains filtered or unexported fields
}
FakeImages implements ImageInterface
func (*FakeImages) Create ¶
func (c *FakeImages) Create(ctx context.Context, image *v1beta1.Image, opts v1.CreateOptions) (result *v1beta1.Image, err error)
Create takes the representation of a image and creates it. Returns the server's representation of the image, and an error, if there is any.
func (*FakeImages) Delete ¶
func (c *FakeImages) Delete(ctx context.Context, name string, opts v1.DeleteOptions) error
Delete takes name of the image and deletes it. Returns an error if one occurs.
func (*FakeImages) DeleteCollection ¶
func (c *FakeImages) DeleteCollection(ctx context.Context, opts v1.DeleteOptions, listOpts v1.ListOptions) error
DeleteCollection deletes a collection of objects.
func (*FakeImages) Get ¶
func (c *FakeImages) Get(ctx context.Context, name string, options v1.GetOptions) (result *v1beta1.Image, err error)
Get takes name of the image, and returns the corresponding image object, and an error if there is any.
func (*FakeImages) List ¶
func (c *FakeImages) List(ctx context.Context, opts v1.ListOptions) (result *v1beta1.ImageList, err error)
List takes label and field selectors, and returns the list of Images that match those selectors.
func (*FakeImages) Patch ¶
func (c *FakeImages) Patch(ctx context.Context, name string, pt types.PatchType, data []byte, opts v1.PatchOptions, subresources ...string) (result *v1beta1.Image, err error)
Patch applies the patch and returns the patched image.
func (*FakeImages) Update ¶
func (c *FakeImages) Update(ctx context.Context, image *v1beta1.Image, opts v1.UpdateOptions) (result *v1beta1.Image, err error)
Update takes the representation of a image and updates it. Returns the server's representation of the image, and an error, if there is any.
func (*FakeImages) UpdateStatus ¶
func (c *FakeImages) UpdateStatus(ctx context.Context, image *v1beta1.Image, opts v1.UpdateOptions) (*v1beta1.Image, error)
UpdateStatus was generated because the type contains a Status member. Add a +genclient:noStatus comment above the type to avoid generating UpdateStatus().
func (*FakeImages) Watch ¶
func (c *FakeImages) Watch(ctx context.Context, opts v1.ListOptions) (watch.Interface, error)
Watch returns a watch.Interface that watches the requested images.
type FakeShipwrightV1beta1 ¶
func (*FakeShipwrightV1beta1) ImageImports ¶
func (c *FakeShipwrightV1beta1) ImageImports(namespace string) v1beta1.ImageImportInterface
func (*FakeShipwrightV1beta1) Images ¶
func (c *FakeShipwrightV1beta1) Images(namespace string) v1beta1.ImageInterface
func (*FakeShipwrightV1beta1) RESTClient ¶
func (c *FakeShipwrightV1beta1) RESTClient() rest.Interface
RESTClient returns a RESTClient that is used to communicate with API server by this client implementation.