v1beta1

package
v0.0.4 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 11, 2022 License: Apache-2.0 Imports: 10 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func NewFilteredImageImportInformer

func NewFilteredImageImportInformer(client versioned.Interface, namespace string, resyncPeriod time.Duration, indexers cache.Indexers, tweakListOptions internalinterfaces.TweakListOptionsFunc) cache.SharedIndexInformer

NewFilteredImageImportInformer constructs a new informer for ImageImport type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.

func NewFilteredImageInformer

func NewFilteredImageInformer(client versioned.Interface, namespace string, resyncPeriod time.Duration, indexers cache.Indexers, tweakListOptions internalinterfaces.TweakListOptionsFunc) cache.SharedIndexInformer

NewFilteredImageInformer constructs a new informer for Image type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.

func NewImageImportInformer

func NewImageImportInformer(client versioned.Interface, namespace string, resyncPeriod time.Duration, indexers cache.Indexers) cache.SharedIndexInformer

NewImageImportInformer constructs a new informer for ImageImport type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.

func NewImageInformer

func NewImageInformer(client versioned.Interface, namespace string, resyncPeriod time.Duration, indexers cache.Indexers) cache.SharedIndexInformer

NewImageInformer constructs a new informer for Image type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.

Types

type ImageImportInformer

type ImageImportInformer interface {
	Informer() cache.SharedIndexInformer
	Lister() v1beta1.ImageImportLister
}

ImageImportInformer provides access to a shared informer and lister for ImageImports.

type ImageInformer

type ImageInformer interface {
	Informer() cache.SharedIndexInformer
	Lister() v1beta1.ImageLister
}

ImageInformer provides access to a shared informer and lister for Images.

type Interface

type Interface interface {
	// Images returns a ImageInformer.
	Images() ImageInformer
	// ImageImports returns a ImageImportInformer.
	ImageImports() ImageImportInformer
}

Interface provides access to all the informers in this group version.

func New

New returns a new Interface.

Jump to